import { LitElement, PropertyValues, TemplateResult } from "lit";
import { AssetDescriptor } from "@openremote/model";
import OrIconSet from "./or-icon-set";
export { OrIconSet };
export declare class IconSetAddedEvent extends CustomEvent<void> {
    static readonly NAME = "or-iconset-added";
    constructor();
}
declare global {
    export interface HTMLElementEventMap {
        [IconSetAddedEvent.NAME]: IconSetAddedEvent;
    }
}
export interface IconSet {
    getIconTemplate: (icon: string) => TemplateResult;
    onAdd?: () => void;
}
export declare function createSvgIconSet(size: number, icons: {
    [name: string]: string;
}): IconSet;
export declare function createMdiIconSet(managerUrl: string): IconSet;
declare class ORIconSets {
    private _icons;
    private _defaultIconSet?;
    addIconSet(name: string, iconSet: IconSet): void;
    getIconSet(name: string): IconSet;
    getIconTemplate(icon: string | undefined): TemplateResult;
}
export declare const IconSets: ORIconSets;
export declare function getAssetDescriptorIconTemplate(descriptor: AssetDescriptor | undefined, fallbackColor?: string | undefined, fallbackIcon?: string | undefined, overrideColor?: string | undefined, overrideIcon?: string | undefined): TemplateResult;
export declare class OrIcon extends LitElement {
    static get styles(): import("lit").CSSResult[];
    icon?: string;
    protected _iconTemplate?: TemplateResult;
    protected _handler: (evt: Event) => void;
    protected render(): TemplateResult;
    disconnectedCallback(): void;
    protected shouldUpdate(changedProperties: PropertyValues): boolean;
    protected _updateIcon(): void;
}
